import { ClipboardModel, Path } from "tree-finder";
export class JupyterClipboard {
    constructor() {
        this.clipboardModel = new ClipboardModel();
        this.srcDrive = null;
        this.destDrive = null;
        this.clipboardModel.deleteSub.subscribe(memo => {
            Promise.all(memo.map(s => this._onDelete(s)));
        });
        this.clipboardModel.pasteSub.subscribe(({ destination, doCut, memo }) => {
            const destPathstr = Path.fromarray(destination.kind === "dir" ? destination.path : destination.path.slice(0, -1));
            Promise.all(memo.map(s => this._onPaste(s, destPathstr, doCut)));
        });
    }
    copySelection(contentsModel, drive) {
        this.srcDrive = drive;
        this.clipboardModel.copySelection(contentsModel);
    }
    cutSelection(contentsModel, drive) {
        this.srcDrive = drive;
        this.clipboardModel.cutSelection(contentsModel);
    }
    deleteSelection(contentsModel, drive) {
        this.srcDrive = drive;
        this.clipboardModel.deleteSelection(contentsModel);
    }
    pasteSelection(contentsModel, drive) {
        this.destDrive = drive;
        this.clipboardModel.pasteSelection(contentsModel);
    }
    async _onDelete(src) {
        const srcPathstr = Path.fromarray(src.path);
        await this.srcDrive.delete(srcPathstr);
    }
    async _onPaste(src, destPathstr, doCut) {
        const srcPathstr = Path.fromarray(src.path);
        await this.destDrive.copy(srcPathstr, destPathstr);
        if (doCut) {
            await this.srcDrive.delete(srcPathstr);
        }
    }
}
(function (JupyterClipboard) {
    JupyterClipboard.defaultClipboard = new JupyterClipboard();
})(JupyterClipboard || (JupyterClipboard = {}));
//# sourceMappingURL=clipboard.js.map