/******************************************************************************
 *
 * Copyright (c) 2019, the jupyter-fs authors.
 *
 * This file is part of the jupyter-fs library, distributed under the terms of
 * the Apache License 2.0.  The full license can be found in the LICENSE file.
 *
 */
import { ILayoutRestorer, IRouter, JupyterFrontEnd } from "@jupyterlab/application";
import { WidgetTracker } from "@jupyterlab/apputils";
import { IWindowResolver } from "@jupyterlab/apputils";
import { IDocumentManager } from "@jupyterlab/docmanager";
import { Contents, ContentsManager } from "@jupyterlab/services";
import { IDisposable } from "@lumino/disposable";
import { Widget } from "@lumino/widgets";
import { IContentRow, TreeFinderPanelElement } from "tree-finder";
import { IFSResource } from "./filesystem";
export declare class JupyterContents {
    constructor(cm: ContentsManager, drive?: string);
    get(path: string): Promise<JupyterContents.IJupyterContentRow>;
    readonly cm: ContentsManager;
    readonly drive: string;
}
export declare namespace JupyterContents {
    interface IJupyterContentRow extends Omit<Contents.IModel, "path" | "content" | "type">, IContentRow {
    }
    function toFullPath(path: string, drive?: string): string;
    function toLocalPath(path: string): string;
    function toJupyterContentRow(row: Contents.IModel, cm: ContentsManager, drive: string): IJupyterContentRow;
}
export declare class TreeFinderTracker extends WidgetTracker<TreeFinder> {
    add(finder: TreeFinder): Promise<void>;
    remove(finder: TreeFinder): void;
    findByDrive(drive: string): TreeFinder;
    hasByDrive(drive: string): boolean;
    private _onWidgetDisposed;
    private _finders;
}
export declare class TreeFinder extends Widget {
    constructor({ app, rootPath, caption, id, }: TreeFinder.IOptions);
    reload(): void;
    restore(): void;
    refresh(): void;
    protected onBeforeShow(msg: any): void;
    protected onResize(msg: any): void;
    get model(): import("tree-finder").ContentsModel<JupyterContents.IJupyterContentRow>;
    get selection(): import("tree-finder").Content<JupyterContents.IJupyterContentRow>[];
    get selectionPathstrs(): string[];
    cm: JupyterContents;
    table: HTMLTableElement;
    tree: HTMLElement;
    readonly commandIds: TreeFinder.ICommandIds;
    readonly node: TreeFinderPanelElement<JupyterContents.IJupyterContentRow>;
}
export declare namespace TreeFinder {
    const commandNames: readonly ["copy", "cut", "delete", "open", "paste", "rename"];
    type ICommandIds = {
        [k in typeof commandNames[number]]: string;
    };
    interface IOptions {
        app: JupyterFrontEnd;
        rootPath?: string;
        caption?: string;
        id?: string;
    }
    interface ISidebarProps extends IOptions {
        manager: IDocumentManager;
        paths: JupyterFrontEnd.IPaths;
        resolver: IWindowResolver;
        restorer: ILayoutRestorer;
        router: IRouter;
        side?: string;
    }
    function sidebarFromResource(resource: IFSResource, props: TreeFinder.ISidebarProps): IDisposable;
    function sidebar({ app, manager, paths, resolver, restorer, router, rootPath, caption, id, side, }: TreeFinder.ISidebarProps): IDisposable;
}
